@@ -1,6 +1,6 @@
 #' @method clusters smerc_cluster
 #' @export
-clusters.smerc_cluster = function(x, idx = seq_along(x$clusters), ...) {
+clusters.smerc_cluster <- function(x, idx = seq_along(x$clusters), ...) {
   if (min(idx) < 1 | max(idx) > length(x$clusters)) {
     stop("invalid idx values")
   }
