@@ -17,6 +17,7 @@
 #' @author Joshua French
 #' @export
 #' @examples
+#' set.seed(1)
 #' data(nydf)
 #' coords <- with(nydf, cbind(longitude, latitude))
 #' out <- scan.test(
@@ -24,19 +25,17 @@
 #'   pop = nydf$pop, alpha = 0.2, longlat = TRUE,
 #'   nsim = 9
 #' )
-#' data(nypoly)
-#' library(sp)
-#' # plot all clusters
-#' plot(nypoly, col = color.clusters(out), axes = TRUE)
-#' # zoom in on small cluster
-#' plot(nypoly,
-#'   col = color.clusters(out),
-#'   xlim = c(400000, 450000),
-#'   ylim = c(4750000, 4800000)
-#' )
-#' # plot only clusters 1 and 3
-#' plot(nypoly, col = color.clusters(out, idx = c(1, 3)))
-color.clusters <- function(x, idx = seq_along(x$clusters), col = grDevices::hcl.colors(length(idx))) {
+#' #' # better plotting
+#' if (require("sf", quietly = TRUE)) {
+#'    data(nysf)
+#'    plot(st_geometry(nysf), col = color.clusters(out))
+#'    # plot only clusters 2 and 3
+#'    plot(st_geometry(nysf),
+#'         col = color.clusters(out, idx = c(2, 3)),
+#'         border = "white")
+#' }
+color.clusters <- function(x, idx = seq_along(x$clusters),
+                           col = grDevices::hcl.colors(length(idx))) {
   if (!any(is.element(class(x), c("scan", "smerc_cluster")))) {
     stop("x should be an object of class scan or smerc_cluster.")
   }
@@ -47,9 +46,9 @@ color.clusters <- function(x, idx = seq_along(x$clusters), col = grDevices::hcl.
     stop("The number of colors must match the length of idx.")
   }
 
-  mycol <- numeric(nrow(x$coords))
-  for (i in seq_along(x$clusters)) {
-    mycol[x$clusters[[i]]$loc] <- col[i]
+  mycol <- rep(NA, nrow(x$coords))
+  for (i in seq_along(idx)) {
+    mycol[x$clusters[[idx[i]]]$loc] <- col[i]
   }
   return(mycol)
 }
